# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.
"""Entrypoint for the kernel gateway package."""
from .gatewayapp import launch_instance

from ._version import version_info, __version__
